Struct blockifier::execution::call_info::CallInfo
source · pub struct CallInfo {
pub call: CallEntryPoint,
pub execution: CallExecution,
pub resources: ExecutionResources,
pub inner_calls: Vec<CallInfo>,
pub storage_read_values: Vec<StarkFelt>,
pub accessed_storage_keys: HashSet<StorageKey>,
}Expand description
Represents the full effects of executing an entry point, including the inner calls it invoked.
Fields
call: CallEntryPointexecution: CallExecutionresources: ExecutionResourcesinner_calls: Vec<CallInfo>storage_read_values: Vec<StarkFelt>accessed_storage_keys: HashSet<StorageKey>Implementations
sourceimpl CallInfo
impl CallInfo
sourcepub fn get_executed_class_hashes(&self) -> HashSet<ClassHash>
pub fn get_executed_class_hashes(&self) -> HashSet<ClassHash>
Returns the set of class hashes that were executed during this call execution.
sourcepub fn get_visited_storage_entries(&self) -> HashSet<StorageEntry>
pub fn get_visited_storage_entries(&self) -> HashSet<StorageEntry>
Returns the set of storage entries visited during this call execution.
sourcepub fn get_sorted_l2_to_l1_payload_lengths(
&self
) -> TransactionExecutionResult<Vec<usize>>
pub fn get_sorted_l2_to_l1_payload_lengths( &self ) -> TransactionExecutionResult<Vec<usize>>
Returns a list of Starknet L2ToL1Payload length collected during the execution, sorted by the order in which they were sent.
sourcepub fn get_number_of_events(&self) -> usize
pub fn get_number_of_events(&self) -> usize
Returns the sum of events in CallInfo and its inner_calls