pub struct StarknetResources {
pub calldata_length: usize,
pub state_changes_for_fee: StateChangesCount,
pub message_cost_info: MessageL1CostInfo,
pub l1_handler_payload_size: Option<usize>,
pub n_events: usize,
/* private fields */
}Expand description
Containes all the L2 resources consumed by a transaction
Fields
calldata_length: usizestate_changes_for_fee: StateChangesCountmessage_cost_info: MessageL1CostInfol1_handler_payload_size: Option<usize>n_events: usizeImplementations
Sourceimpl StarknetResources
impl StarknetResources
pub fn new<'a>( calldata_length: usize, signature_length: usize, code_size: usize, state_changes_count: StateChangesCount, l1_handler_payload_size: Option<usize>, call_infos: impl Iterator<Item = &'a CallInfo> + Clone, ) -> Self
Sourcepub fn to_gas_vector(
&self,
versioned_constants: &VersionedConstants,
use_kzg_da: bool,
) -> GasVector
pub fn to_gas_vector( &self, versioned_constants: &VersionedConstants, use_kzg_da: bool, ) -> GasVector
Returns the gas cost of the starknet resources, summing all components.
pub fn get_calldata_and_signature_cost( &self, versioned_constants: &VersionedConstants, ) -> GasVector
Sourcepub fn get_messages_cost(&self) -> GasVector
pub fn get_messages_cost(&self) -> GasVector
Returns an estimation of the gas usage for processing L1<>L2 messages on L1. Accounts for both Starknet and SHARP contracts.
Sourcepub fn calculate_message_l1_resources(&self) -> (usize, usize)
pub fn calculate_message_l1_resources(&self) -> (usize, usize)
Calculates the L1 resources used by L1<>L2 messages. Returns the total message segment length and the gas weight.
Sourcepub fn get_code_cost(
&self,
versioned_constants: &VersionedConstants,
) -> GasVector
pub fn get_code_cost( &self, versioned_constants: &VersionedConstants, ) -> GasVector
Returns the gas cost of declared class codes.
Sourcepub fn get_state_changes_cost(&self, use_kzg_da: bool) -> GasVector
pub fn get_state_changes_cost(&self, use_kzg_da: bool) -> GasVector
Returns the gas cost of the transaction’s state changes.
Sourcepub fn get_events_cost(
&self,
versioned_constants: &VersionedConstants,
) -> GasVector
pub fn get_events_cost( &self, versioned_constants: &VersionedConstants, ) -> GasVector
Returns the gas cost of the transaction’s emmited events.
pub fn get_onchain_data_segment_length(&self) -> usize